@@ -1,2 +1,2 @@
-import neurosity.config
+from neurosity.config import PyRebase
 from neurosity.neurosity import neurosity_sdk
\ No newline at end of file
